# Simple Bengali Letters Quiz

A simple PyQt5 application to help with learning Bengali script.

It displays a single Bengali character with multiple choices for the
corresponding transliteration into Latin characters.

Each consecutive correct answer scores one point; an incorrect answer
resets your score to zero. Go for a high score!


# Installation and running the application

The application should install in the standard way for a Python package, e.g., via `pip`:

```
pip install bengali_letters

```

Or using the `setup.py` script:
    
```
python setup.py install
```

Simply run `bengali_letters` to launch the application.
